NAME = "blue_south"

ICON = "🌀"

DESCRIPTION = f"{ICON} AI for Global South: Free from Big Tech."

VERSION = "4.9.1"

REPO_NAME = "blue-south"

MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-south/marquee.png?raw=true"

ALIAS = "@south"


def fullname() -> str:
    return f"{NAME}-{VERSION}"



import abcli
import blue_options
import blue_objects
from blue_objects import README
import gizai


items = README.Items(
    [
        {
            "name": module.NAME,
            "marquee": module.MARQUEE,
            "description": " ".join(
                [
                    module.DESCRIPTION.replace(module.ICON, "").strip(),
                    " [![PyPI version](https://img.shields.io/pypi/v/{}.svg)](https://pypi.org/project/{}/)".format(
                        module.NAME, module.NAME
                    ),
                ]
            ),
            "url": f"https://github.com/kamangir/{module.REPO_NAME}",
        }
        for module in [
            abcli,
            blue_options,
            blue_objects,
            gizai,
        ]
    ]
)
